@@ -98,6 +98,39 @@ def setup_logging(verbose: bool = False):
     )
 
 
+def setup_logging_with_rotation(verbose: bool = False, project_dir: Path | None = None):
+    """Setup logging configuration with file rotation for daemon mode."""
+    from logging.handlers import RotatingFileHandler
+
+    if project_dir is None:
+        project_dir = Path.cwd()
+
+    level = logging.DEBUG if verbose else logging.INFO
+    log_file = project_dir / ".devloop" / "devloop.log"
+    log_file.parent.mkdir(parents=True, exist_ok=True)
+
+    # Create rotating file handler
+    # maxBytes: 10MB per file
+    # backupCount: keep 3 rotated files (total ~40MB max)
+    rotating_handler = RotatingFileHandler(
+        filename=str(log_file),
+        maxBytes=10 * 1024 * 1024,  # 10MB
+        backupCount=3,
+    )
+
+    # Format: timestamp | level | logger | message
+    formatter = logging.Formatter(
+        "%(asctime)s | %(levelname)-8s | %(name)-20s | %(message)s",
+        datefmt="%Y-%m-%d %H:%M:%S",
+    )
+    rotating_handler.setFormatter(formatter)
+
+    # Configure root logger
+    root_logger = logging.getLogger()
+    root_logger.setLevel(level)
+    root_logger.addHandler(rotating_handler)
+
+
 def run_daemon(path: Path, config_path: Path | None, verbose: bool):
     """Run devloop in daemon/background mode."""
     import os
@@ -125,16 +158,11 @@ def run_daemon(path: Path, config_path: Path | None, verbose: bool):
     os.setsid()
     os.umask(0)
 
-    # Redirect stdout/stderr to log file
-    log_file = project_dir / ".devloop" / "devloop.log"
-    log_file.parent.mkdir(parents=True, exist_ok=True)
+    # Setup logging with rotation BEFORE redirecting file descriptors
+    setup_logging_with_rotation(verbose, project_dir)
 
-    with open(log_file, "a") as f:
-        os.dup2(f.fileno(), sys.stdout.fileno())
-        os.dup2(f.fileno(), sys.stderr.fileno())
-
-    # Setup logging for daemon
-    setup_logging(verbose)
+    # Don't redirect stdout/stderr - let logging handlers manage it
+    # This prevents unbounded log file growth
 
     # Write PID file
     pid_file = project_dir / ".devloop" / "devloop.pid"
@@ -200,6 +228,42 @@ def watch(
         console.print("\n[yellow]Shutting down...[/yellow]")
 
 
+async def _cleanup_old_data(context_store, event_store, interval_hours: int = 1):
+    """Periodically clean up old findings and events to prevent disk fill-up.
+
+    Args:
+        context_store: Context store instance
+        event_store: Event store instance
+        interval_hours: How often to run cleanup (default: 1 hour)
+    """
+    cleanup_interval = interval_hours * 60 * 60  # Convert to seconds
+    context_retention_hours = 7 * 24  # Keep 7 days of findings
+    event_retention_days = 30  # Keep 30 days of events
+
+    while True:
+        try:
+            await asyncio.sleep(cleanup_interval)
+
+            # Clean up old context findings
+            findings_removed = await context_store.cleanup_old_findings(
+                hours_to_keep=context_retention_hours
+            )
+
+            # Clean up old events
+            events_removed = await event_store.cleanup_old_events(
+                days_to_keep=event_retention_days
+            )
+
+            console.print(
+                f"[dim]Cleanup: removed {findings_removed} old findings, {events_removed} old events[/dim]"
+            )
+
+        except asyncio.CancelledError:
+            break
+        except Exception as e:
+            console.print(f"[yellow]Cleanup error: {e}[/yellow]")
+
+
 async def watch_async(path: Path, config_path: Path | None):
     """Async watch implementation."""
     # Load configuration
@@ -232,6 +296,9 @@ async def watch_async(path: Path, config_path: Path | None):
     fs_config = {"watch_paths": [str(path)]}
     fs_collector = FileSystemCollector(event_bus=event_bus, config=fs_config)
 
+    # Start cleanup task (run every hour to remove old findings/events)
+    cleanup_task = asyncio.create_task(_cleanup_old_data(context_store, event_store))
+
     # Create and register agents based on configuration
     if config.is_agent_enabled("linter"):
         linter_config = config.get_agent_config("linter") or {}
@@ -324,9 +391,16 @@ async def watch_async(path: Path, config_path: Path | None):
     await shutdown_event.wait()
 
     # Stop everything
+    cleanup_task.cancel()
     await agent_manager.stop_all()
     await fs_collector.stop()
 
+    # Wait for cleanup task to finish
+    try:
+        await cleanup_task
+    except asyncio.CancelledError:
+        pass
+
 
 @app.command()
 def init(
@@ -334,6 +408,9 @@ def init(
     skip_config: bool = typer.Option(
         False, "--skip-config", help="Skip creating configuration file"
     ),
+    non_interactive: bool = typer.Option(
+        False, "--non-interactive", help="Skip interactive prompts for optional agents"
+    ),
 ):
     """Initialize devloop in a project."""
     claude_dir = path / ".devloop"
@@ -341,8 +418,9 @@ def init(
     if claude_dir.exists():
         console.print(f"[yellow]Directory already exists: {claude_dir}[/yellow]")
     else:
-        claude_dir.mkdir(exist_ok=True)
+        claude_dir.mkdir(parents=True, exist_ok=True)
         console.print(f"[green]✓[/green] Created: {claude_dir}")
+
     # Create default configuration
     if not skip_config:
         config_file = claude_dir / "agents.json"
@@ -351,9 +429,138 @@ def init(
                 f"[yellow]Configuration already exists: {config_file}[/yellow]"
             )
         else:
-            config = Config.default_config()
+            optional_agents = {}
+
+            # Interactive prompts for optional agents (unless non-interactive mode)
+            if not non_interactive:
+                console.print("\n[cyan]Optional Agents Setup[/cyan]")
+                console.print("The following optional agents can be enabled:\n")
+
+                # Snyk prompt
+                if typer.confirm(
+                    "Enable [yellow]Snyk[/yellow] agent for security vulnerability scanning?",
+                    default=False,
+                ):
+                    optional_agents["snyk"] = True
+                    console.print(
+                        "  [green]✓[/green] Snyk agent enabled (requires SNYK_TOKEN env var)"
+                    )
+
+                # Code Rabbit prompt
+                if typer.confirm(
+                    "Enable [yellow]Code Rabbit[/yellow] agent for code analysis insights?",
+                    default=False,
+                ):
+                    optional_agents["code-rabbit"] = True
+                    console.print(
+                        "  [green]✓[/green] Code Rabbit agent enabled (requires CODE_RABBIT_API_KEY env var)"
+                    )
+
+                # CI Monitor prompt
+                if typer.confirm(
+                    "Enable [yellow]CI Monitor[/yellow] agent to track CI/CD pipeline status?",
+                    default=False,
+                ):
+                    optional_agents["ci-monitor"] = True
+                    console.print("  [green]✓[/green] CI Monitor agent enabled")
+
+                # Pyodide WASM Sandbox prompt and installation
+                from devloop.cli.pyodide_installer import prompt_pyodide_installation
+
+                prompt_pyodide_installation(non_interactive=False)
+
+            config = Config()
+            config._config = config._get_default_config(optional_agents=optional_agents)
             config.save(config_file)
-            console.print(f"[green]✓[/green] Created: {config_file}")
+            console.print(f"\n[green]✓[/green] Created: {config_file}")
+
+    # Check for and manage AGENTS.md with Beads integration
+    agents_md = path / "AGENTS.md"
+    beads_template = claude_dir / "beads_template.md"
+
+    if beads_template.exists():
+        beads_content = beads_template.read_text()
+
+        if agents_md.exists():
+            # Check if AGENTS.md already has Beads section
+            content = agents_md.read_text()
+            if "Task Management with Beads" not in content:
+                # Inject Beads section after first heading
+                lines = content.split("\n")
+                insert_pos = 0
+                for i, line in enumerate(lines):
+                    if line.startswith("# ") and i > 0:
+                        insert_pos = i + 1
+                        break
+
+                # Insert Beads section
+                new_content = (
+                    "\n".join(lines[:insert_pos])
+                    + "\n\n"
+                    + beads_content
+                    + "\n\n"
+                    + "\n".join(lines[insert_pos:])
+                )
+                agents_md.write_text(new_content)
+                console.print(
+                    f"[green]✓[/green] Injected Beads section into {agents_md}"
+                )
+        else:
+            # Create AGENTS.md from template
+            template_header = """# Development Workflow
+
+This project uses background agents and Beads for task management.
+
+"""
+            agents_md.write_text(template_header + beads_content)
+            console.print(f"[green]✓[/green] Created: {agents_md}")
+
+    # Handle Claude.md symlink for Claude code tools
+    claude_md = path / "CLAUDE.md"
+    if claude_md.exists():
+        if claude_md.is_symlink():
+            target = claude_md.resolve()
+            if target.name == "AGENTS.md":
+                console.print("\n[green]✓[/green] Claude symlink already set up")
+            else:
+                console.print(
+                    "\n[yellow]Warning:[/yellow] CLAUDE.md exists but doesn't point to AGENTS.md"
+                )
+        else:
+            console.print("\n[yellow]Note:[/yellow] CLAUDE.md exists as a regular file")
+            console.print("  [cyan]Consider replacing it with a symlink:[/cyan]")
+            console.print("    rm CLAUDE.md && ln -s AGENTS.md CLAUDE.md")
+    else:
+        # Create symlink for Claude
+        try:
+            claude_md.symlink_to("AGENTS.md")
+            console.print(f"[green]✓[/green] Created: {claude_md} -> AGENTS.md")
+        except Exception as e:
+            console.print(
+                f"[yellow]Warning:[/yellow] Could not create CLAUDE.md symlink: {e}"
+            )
+
+    # Set up Claude Code slash commands
+    claude_commands_dir = path / ".claude" / "commands"
+    template_commands_dir = Path(__file__).parent / "templates" / "claude_commands"
+
+    if template_commands_dir.exists():
+        claude_commands_dir.mkdir(parents=True, exist_ok=True)
+
+        # Copy command templates
+        import shutil
+
+        commands_copied = []
+        for template_file in template_commands_dir.glob("*.md"):
+            dest_file = claude_commands_dir / template_file.name
+            if not dest_file.exists():
+                shutil.copy2(template_file, dest_file)
+                commands_copied.append(template_file.stem)
+
+        if commands_copied:
+            console.print(f"\n[green]✓[/green] Created Claude Code slash commands:")
+            for cmd in commands_copied:
+                console.print(f"  • /{cmd}")
 
     console.print("\n[green]✓[/green] Initialized!")
     console.print("\nNext steps:")
